@@ -1,7 +1,7 @@
 // FIXME(thaJeztah): remove once we are a module; the go:build directive prevents go from downgrading language version to go1.16:
 //go:build go1.23
 
-package system // import "github.com/docker/docker/api/server/router/system"
+package system
 
 import (
 	"github.com/docker/docker/api/server/router"
