@@ -1,4 +1,4 @@
-package libcontainerd // import "github.com/docker/docker/libcontainerd"
+package libcontainerd
 
 import (
 	"context"
@@ -13,7 +13,7 @@ import (
 // NewClient creates a new libcontainerd client from a containerd client
 func NewClient(ctx context.Context, cli *containerd.Client, stateDir, ns string, b libcontainerdtypes.Backend) (libcontainerdtypes.Client, error) {
 	if !system.ContainerdRuntimeSupported() {
-		return local.NewClient(ctx, cli, stateDir, ns, b)
+		return local.NewClient(ctx, b)
 	}
 	return remote.NewClient(ctx, cli, stateDir, ns, b)
 }
